@@ -9,7 +9,6 @@
 
 #include <KFileItem>
 #include <KPluginFactory>
-#include <KPluginLoader>
 
 #include <QAction>
 #include <QDir>
@@ -22,7 +21,11 @@
 using namespace std;
 using namespace Data;
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+K_PLUGIN_CLASS_WITH_JSON(SyncthingFileItemAction, "metadata.json");
+#else
 K_PLUGIN_FACTORY(SyncthingFileItemActionFactory, registerPlugin<SyncthingFileItemAction>();)
+#endif
 
 struct SyncthingItem {
     SyncthingItem(const SyncthingDir *dir, const QString &path);
@@ -70,7 +73,7 @@ QList<QAction *> SyncthingFileItemAction::actions(const KFileItemListProperties
         parentWidget->installEventFilter(this);
     }
 
-    topLevelActions << new SyncthingMenuAction(fileItemInfo, subActions, this);
+    topLevelActions << new SyncthingMenuAction(fileItemInfo, subActions, parentWidget);
     return topLevelActions;
 }
 
@@ -103,13 +106,13 @@ DirStats::DirStats(const QList<const SyncthingDir *> &dirs)
 
 QList<QAction *> SyncthingFileItemAction::createActions(const KFileItemListProperties &fileItemInfo, QObject *parent)
 {
-    QList<QAction *> actions;
+    auto actions = QList<QAction *>();
     auto &data = s_data;
     auto &connection = data.connection();
     const auto &dirs = connection.dirInfo();
 
     // get all paths
-    QStringList paths;
+    auto paths = QStringList();
     paths.reserve(fileItemInfo.items().size());
     const auto items = fileItemInfo.items();
     for (const KFileItem &item : items) {
@@ -172,7 +175,7 @@ QList<QAction *> SyncthingFileItemAction::createActions(const KFileItemListPrope
 
         // rescan item
         actions << new QAction(QIcon::fromTheme(QStringLiteral("folder-sync")),
-            detectedDirs.size() == 1 ? tr("Rescan \"%1\"").arg(detectedDirs.front()->displayName()) : tr("Rescan selected directories"), parent);
+            detectedDirs.size() == 1 ? tr("Rescan \"%1\"").arg(detectedDirs.front()->displayName()) : tr("Rescan selected folders"), parent);
         if (connection.isConnected() && !detectedDirsStats.allPaused) {
             for (const SyncthingDir *dir : std::as_const(detectedDirs)) {
                 connect(actions.back(), &QAction::triggered, bind(&SyncthingFileItemActionStaticData::rescanDir, &data, dir->id, QString()));
@@ -185,10 +188,10 @@ QList<QAction *> SyncthingFileItemAction::createActions(const KFileItemListPrope
         // pause/resume item
         if (detectedDirsStats.anyPaused) {
             actions << new QAction(QIcon::fromTheme(QStringLiteral("media-playback-start")),
-                detectedDirs.size() == 1 ? tr("Resume \"%1\"").arg(detectedDirs.front()->displayName()) : tr("Resume selected directories"), parent);
+                detectedDirs.size() == 1 ? tr("Resume \"%1\"").arg(detectedDirs.front()->displayName()) : tr("Resume selected folders"), parent);
         } else {
             actions << new QAction(QIcon::fromTheme(QStringLiteral("media-playback-pause")),
-                detectedDirs.size() == 1 ? tr("Pause \"%1\"").arg(detectedDirs.front()->displayName()) : tr("Pause selected directories"), parent);
+                detectedDirs.size() == 1 ? tr("Pause \"%1\"").arg(detectedDirs.front()->displayName()) : tr("Pause selected folders"), parent);
         }
         if (connection.isConnected()) {
             connect(actions.back(), &QAction::triggered,
@@ -203,8 +206,7 @@ QList<QAction *> SyncthingFileItemAction::createActions(const KFileItemListPrope
     if (!containingDirs.isEmpty()) {
         // rescan item
         actions << new QAction(QIcon::fromTheme(QStringLiteral("folder-sync")),
-            containingDirs.size() == 1 ? tr("Rescan \"%1\"").arg(containingDirs.front()->displayName()) : tr("Rescan containing directories"),
-            parent);
+            containingDirs.size() == 1 ? tr("Rescan \"%1\"").arg(containingDirs.front()->displayName()) : tr("Rescan containing folders"), parent);
         if (connection.isConnected() && !containingDirsStats.allPaused) {
             for (const SyncthingDir *dir : std::as_const(containingDirs)) {
                 connect(actions.back(), &QAction::triggered, bind(&SyncthingFileItemActionStaticData::rescanDir, &data, dir->id, QString()));
@@ -216,12 +218,11 @@ QList<QAction *> SyncthingFileItemAction::createActions(const KFileItemListPrope
         // pause/resume item
         if (containingDirsStats.anyPaused) {
             actions << new QAction(QIcon::fromTheme(QStringLiteral("media-playback-start")),
-                containingDirs.size() == 1 ? tr("Resume \"%1\"").arg(containingDirs.front()->displayName()) : tr("Resume containing directories"),
+                containingDirs.size() == 1 ? tr("Resume \"%1\"").arg(containingDirs.front()->displayName()) : tr("Resume containing folders"),
                 parent);
         } else {
             actions << new QAction(QIcon::fromTheme(QStringLiteral("media-playback-pause")),
-                containingDirs.size() == 1 ? tr("Pause \"%1\"").arg(containingDirs.front()->displayName()) : tr("Pause containing directories"),
-                parent);
+                containingDirs.size() == 1 ? tr("Pause \"%1\"").arg(containingDirs.front()->displayName()) : tr("Pause containing folders"), parent);
         }
         if (connection.isConnected()) {
             connect(actions.back(), &QAction::triggered,
