@@ -10,8 +10,8 @@
     </message>
     <message>
         <location filename="../syncthingdiractions.cpp" line="43"/>
-        <source>Directory info for %1</source>
-        <translation>Verzeichnisinfo für %1</translation>
+        <source>Folder info for %1</source>
+        <translation>Ordnerinfo für %1</translation>
     </message>
     <message>
         <location filename="../syncthingdiractions.cpp" line="44"/>
@@ -50,61 +50,61 @@
 <context>
     <name>SyncthingFileItemAction</name>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="156"/>
+        <location filename="../syncthingfileitemaction.cpp" line="159"/>
         <source>Rescan selected items</source>
         <translation>Auswahl neu scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="175"/>
-        <source>Rescan selected directories</source>
-        <translation>Ausgewählte Verzeichnisse neu scannen</translation>
+        <location filename="../syncthingfileitemaction.cpp" line="178"/>
+        <source>Rescan selected folders</source>
+        <translation>Ausgewählte Ordner neu scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="188"/>
-        <source>Resume selected directories</source>
-        <translation>Ausgewählte verzeichnisse fortsetzen</translation>
+        <location filename="../syncthingfileitemaction.cpp" line="191"/>
+        <source>Resume selected folders</source>
+        <translation>Ausgewählte Ordner fortsetzen</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="158"/>
-        <location filename="../syncthingfileitemaction.cpp" line="175"/>
-        <location filename="../syncthingfileitemaction.cpp" line="206"/>
+        <location filename="../syncthingfileitemaction.cpp" line="161"/>
+        <location filename="../syncthingfileitemaction.cpp" line="178"/>
+        <location filename="../syncthingfileitemaction.cpp" line="209"/>
         <source>Rescan &quot;%1&quot;</source>
         <translation>&quot;%1&quot; neu scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="191"/>
-        <source>Pause selected directories</source>
-        <translation>Ausgewählte Verzeichnisse pausieren</translation>
+        <location filename="../syncthingfileitemaction.cpp" line="194"/>
+        <source>Pause selected folders</source>
+        <translation>Ausgewählte Ordner pausieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="206"/>
-        <source>Rescan containing directories</source>
-        <translation>Beinhaltendes Verzeichnis neu scannen</translation>
+        <location filename="../syncthingfileitemaction.cpp" line="209"/>
+        <source>Rescan containing folders</source>
+        <translation>Beinhaltenden Ordner neu scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="219"/>
-        <source>Resume containing directories</source>
-        <translation>Beinhaltendes Verzeichnis fortsetzen</translation>
+        <location filename="../syncthingfileitemaction.cpp" line="221"/>
+        <source>Resume containing folders</source>
+        <translation>Beinhaltende Ordner fortsetzen</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="248"/>
+        <location filename="../syncthingfileitemaction.cpp" line="249"/>
         <source>Not a shared directory</source>
-        <translation>Kein geteiltes Verzeichnis</translation>
+        <translation>Kein geteilter Ordner</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="188"/>
-        <location filename="../syncthingfileitemaction.cpp" line="219"/>
+        <location filename="../syncthingfileitemaction.cpp" line="191"/>
+        <location filename="../syncthingfileitemaction.cpp" line="221"/>
         <source>Resume &quot;%1&quot;</source>
         <translation>&quot;%1&quot; fortsetzen (in &quot;%1&quot;)</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="223"/>
-        <source>Pause containing directories</source>
-        <translation>Beinhaltendes Verzeichnis pausieren</translation>
+        <location filename="../syncthingfileitemaction.cpp" line="225"/>
+        <source>Pause containing folders</source>
+        <translation>Beinhaltenden Ordner pausieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="191"/>
-        <location filename="../syncthingfileitemaction.cpp" line="223"/>
+        <location filename="../syncthingfileitemaction.cpp" line="194"/>
+        <location filename="../syncthingfileitemaction.cpp" line="225"/>
         <source>Pause &quot;%1&quot;</source>
         <translation>&quot;%1&quot; pausieren (in &quot;%1&quot;)</translation>
     </message>
@@ -113,12 +113,12 @@
         <translation type="vanished">Helle Farben verwenden</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="282"/>
+        <location filename="../syncthingfileitemaction.cpp" line="283"/>
         <source>Select Syncthing config ...</source>
         <translation>Syncthing-Konfiguration wählen ...</translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="287"/>
+        <location filename="../syncthingfileitemaction.cpp" line="288"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
@@ -179,17 +179,17 @@
 <context>
     <name>SyncthingMenuAction</name>
     <message>
-        <location filename="../syncthingmenuaction.cpp" line="68"/>
+        <location filename="../syncthingmenuaction.cpp" line="69"/>
         <source>Syncthing</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingmenuaction.cpp" line="79"/>
+        <location filename="../syncthingmenuaction.cpp" line="80"/>
         <source>Syncthing - connecting</source>
         <translation>Syncthing - verbinde</translation>
     </message>
     <message>
-        <location filename="../syncthingmenuaction.cpp" line="81"/>
+        <location filename="../syncthingmenuaction.cpp" line="82"/>
         <source>Syncthing - not connected</source>
         <translation>Syncthing - nicht verbunden</translation>
     </message>
