@@ -10,7 +10,7 @@
     </message>
     <message>
         <location filename="../syncthingdiractions.cpp" line="43"/>
-        <source>Directory info for %1</source>
+        <source>Folder info for %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -50,71 +50,71 @@
 <context>
     <name>SyncthingFileItemAction</name>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="287"/>
+        <location filename="../syncthingfileitemaction.cpp" line="288"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="156"/>
+        <location filename="../syncthingfileitemaction.cpp" line="159"/>
         <source>Rescan selected items</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="175"/>
-        <source>Rescan selected directories</source>
+        <location filename="../syncthingfileitemaction.cpp" line="178"/>
+        <source>Rescan selected folders</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="158"/>
-        <location filename="../syncthingfileitemaction.cpp" line="175"/>
-        <location filename="../syncthingfileitemaction.cpp" line="206"/>
+        <location filename="../syncthingfileitemaction.cpp" line="161"/>
+        <location filename="../syncthingfileitemaction.cpp" line="178"/>
+        <location filename="../syncthingfileitemaction.cpp" line="209"/>
         <source>Rescan &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="188"/>
-        <source>Resume selected directories</source>
+        <location filename="../syncthingfileitemaction.cpp" line="191"/>
+        <source>Resume selected folders</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfileitemaction.cpp" line="194"/>
+        <source>Pause selected folders</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfileitemaction.cpp" line="209"/>
+        <source>Rescan containing folders</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfileitemaction.cpp" line="221"/>
+        <source>Resume containing folders</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../syncthingfileitemaction.cpp" line="191"/>
-        <source>Pause selected directories</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfileitemaction.cpp" line="206"/>
-        <source>Rescan containing directories</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfileitemaction.cpp" line="219"/>
-        <source>Resume containing directories</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfileitemaction.cpp" line="188"/>
-        <location filename="../syncthingfileitemaction.cpp" line="219"/>
+        <location filename="../syncthingfileitemaction.cpp" line="221"/>
         <source>Resume &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="223"/>
-        <source>Pause containing directories</source>
+        <location filename="../syncthingfileitemaction.cpp" line="225"/>
+        <source>Pause containing folders</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="191"/>
-        <location filename="../syncthingfileitemaction.cpp" line="223"/>
+        <location filename="../syncthingfileitemaction.cpp" line="194"/>
+        <location filename="../syncthingfileitemaction.cpp" line="225"/>
         <source>Pause &quot;%1&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="248"/>
+        <location filename="../syncthingfileitemaction.cpp" line="249"/>
         <source>Not a shared directory</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfileitemaction.cpp" line="282"/>
+        <location filename="../syncthingfileitemaction.cpp" line="283"/>
         <source>Select Syncthing config ...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -175,17 +175,17 @@
 <context>
     <name>SyncthingMenuAction</name>
     <message>
-        <location filename="../syncthingmenuaction.cpp" line="68"/>
+        <location filename="../syncthingmenuaction.cpp" line="69"/>
         <source>Syncthing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingmenuaction.cpp" line="79"/>
+        <location filename="../syncthingmenuaction.cpp" line="80"/>
         <source>Syncthing - connecting</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingmenuaction.cpp" line="81"/>
+        <location filename="../syncthingmenuaction.cpp" line="82"/>
         <source>Syncthing - not connected</source>
         <translation type="unfinished"></translation>
     </message>
