@@ -40,6 +40,7 @@
 #include <QDesktopServices>
 #include <QGuiApplication>
 #include <QMap>
+#include <QMessageBox>
 #include <QNetworkReply>
 #include <QPalette>
 #include <QQmlEngine>
@@ -68,7 +69,11 @@ static inline QPalette paletteFromTheme(const Plasma::Theme &theme)
 }
 
 SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    : Applet(parent, KPluginMetaData(), data)
+#else
     : Applet(parent, data)
+#endif
     , m_faUrl(QStringLiteral("image://fa/"))
     , m_iconManager(IconManager::instance(&m_palette))
     , m_aboutDlg(nullptr)
@@ -83,9 +88,7 @@ SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
     , m_settingsDlg(nullptr)
     , m_wizard(nullptr)
     , m_imageProvider(nullptr)
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
     , m_webViewDlg(nullptr)
-#endif
     , m_currentConnectionConfig(-1)
     , m_hasInternalErrors(false)
     , m_initialized(false)
@@ -111,6 +114,19 @@ SyncthingApplet::~SyncthingApplet()
 #endif
 }
 
+void showErrorIfSet(const QString &errorMessage)
+{
+    if (errorMessage.isEmpty()) {
+        return;
+    }
+    auto msgBox = new QMessageBox();
+    msgBox->setWindowTitle(QStringLiteral(APP_NAME));
+    msgBox->setAttribute(Qt::WA_DeleteOnClose, true);
+    msgBox->setText(errorMessage);
+    msgBox->setIcon(QMessageBox::Critical);
+    msgBox->show();
+}
+
 void SyncthingApplet::init()
 {
     LOAD_QT_TRANSLATIONS;
@@ -170,9 +186,12 @@ void SyncthingApplet::init()
     if (settings.firstLaunch || settings.fakeFirstLaunch) {
         showWizard();
         settings.firstLaunch = false;
-        Settings::save();
+        saveSettings();
     }
 
+    // show error when settings cannot be restored
+    showErrorIfSet(settings.error);
+
     m_initialized = true;
 }
 
@@ -319,6 +338,12 @@ void SyncthingApplet::updateStatusIconAndTooltip()
     emit connectionStatusChanged();
 }
 
+void SyncthingApplet::saveSettings()
+{
+    Settings::save();
+    showErrorIfSet(Settings::values().error);
+}
+
 QIcon SyncthingApplet::loadForkAwesomeIcon(const QString &name, int size) const
 {
     const auto icon = QtForkAwesome::iconFromId(name);
@@ -348,7 +373,7 @@ void SyncthingApplet::showSettingsDlg()
         // save plasmoid specific settings to disk when applied
         connect(m_settingsDlg, &SettingsDialog::applied, this, &SyncthingApplet::configChanged);
         // save global/general settings to disk when applied
-        connect(m_settingsDlg, &SettingsDialog::applied, &Settings::save);
+        connect(m_settingsDlg, &SettingsDialog::applied, this, &SyncthingApplet::saveSettings);
     }
     centerWidget(m_settingsDlg);
     m_settingsDlg->show();
@@ -388,28 +413,25 @@ void SyncthingApplet::concludeWizard(const QString &errorMessage)
     }
     m_applyingSettingsForWizard = false;
     if (m_wizard) {
-        m_wizard->handleConfigurationApplied(errorMessage);
+        m_wizard->handleConfigurationApplied(errorMessage, &m_connection);
     }
 }
 
 void SyncthingApplet::showWebUI()
 {
+    auto *const dlg = QtGui::showWebUI(m_connection.syncthingUrl(), currentConnectionConfig(), m_webViewDlg);
 #ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
-    if (Settings::values().webView.disabled) {
-#endif
-        QDesktopServices::openUrl(m_connection.syncthingUrl());
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
-    } else {
-        if (!m_webViewDlg) {
-            m_webViewDlg = new WebViewDialog;
-            if (const auto *connectionConfig = currentConnectionConfig()) {
-                m_webViewDlg->applySettings(*connectionConfig, true);
-            }
-            connect(m_webViewDlg, &WebViewDialog::destroyed, this, &SyncthingApplet::handleWebViewDeleted);
-        }
-        m_webViewDlg->show();
-        m_webViewDlg->activateWindow();
+    if (!dlg) {
+        return;
     }
+    if (!m_webViewDlg) {
+        m_webViewDlg = dlg;
+        connect(m_webViewDlg, &WebViewDialog::destroyed, this, &SyncthingApplet::handleWebViewDeleted);
+    }
+    m_webViewDlg->show();
+    m_webViewDlg->activateWindow();
+#else
+    Q_UNUSED(dlg)
 #endif
 }
 
@@ -474,17 +496,15 @@ void SyncthingApplet::showInternalErrorsDialog()
     errorViewDlg->show();
 }
 
-void SyncthingApplet::showDirectoryErrors(unsigned int directoryIndex)
+void SyncthingApplet::showDirectoryErrors(const QString &dirId)
 {
-    const auto &dirs = m_connection.dirInfo();
-    if (directoryIndex >= dirs.size()) {
+    auto row = 0;
+    auto *const dir = m_connection.findDirInfo(dirId, row);
+    if (!dir) {
         return;
     }
-
-    const auto &dir(dirs[directoryIndex]);
-    m_connection.requestDirPullErrors(dir.id);
-
-    auto *const dlg = new DirectoryErrorsDialog(m_connection, dir);
+    m_connection.requestDirPullErrors(dirId);
+    auto *const dlg = new DirectoryErrorsDialog(m_connection, *dir);
     dlg->setAttribute(Qt::WA_DeleteOnClose, true);
     centerWidget(dlg);
     dlg->show();
@@ -536,7 +556,7 @@ void SyncthingApplet::handleDevicesChanged()
 void SyncthingApplet::handleInternalError(
     const QString &errorMsg, SyncthingErrorCategory category, int networkError, const QNetworkRequest &request, const QByteArray &response)
 {
-    if (!InternalError::isRelevant(m_connection, category, networkError)) {
+    if (!InternalError::isRelevant(m_connection, category, errorMsg, networkError)) {
         return;
     }
     auto error = InternalError(errorMsg, request.url(), response);
@@ -565,12 +585,10 @@ void SyncthingApplet::handleAboutDialogDeleted()
     m_aboutDlg = nullptr;
 }
 
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
 void SyncthingApplet::handleWebViewDeleted()
 {
     m_webViewDlg = nullptr;
 }
-#endif
 
 void SyncthingApplet::handleNewNotification(DateTime when, const QString &msg)
 {
@@ -664,6 +682,12 @@ void SyncthingApplet::handleSystemdStatusChanged()
 
 } // namespace Plasmoid
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+namespace Plasmoid {
+K_PLUGIN_CLASS(SyncthingApplet)
+}
+#else
 K_EXPORT_PLASMA_APPLET_WITH_JSON(syncthing, Plasmoid::SyncthingApplet, "metadata.json")
+#endif
 
 #include "syncthingapplet.moc"
