@@ -35,7 +35,11 @@ class IconManager;
 } // namespace Data
 
 namespace QtGui {
+#ifdef SYNCTHINGWIDGETS_NO_WEBVIEW
+using WebViewDialog = void;
+#else
 class WebViewDialog;
+#endif
 class Wizard;
 } // namespace QtGui
 
@@ -123,6 +127,9 @@ public:
     const QList<QtUtilities::ChecklistItem> &passiveStates() const;
     void setPassiveStates(const QList<QtUtilities::ChecklistItem> &passiveStates);
     QString faUrl();
+    Q_INVOKABLE QIcon loadForkAwesomeIcon(const QString &name, int size = 32) const;
+    Q_INVOKABLE QString formatFileSize(quint64 fileSizeInByte) const;
+    Q_INVOKABLE QString substituteTilde(const QString &path) const;
 
 public Q_SLOTS:
     void init() override;
@@ -136,12 +143,10 @@ public Q_SLOTS:
     void showNotificationsDialog();
     void dismissNotifications();
     void showInternalErrorsDialog();
-    void showDirectoryErrors(unsigned int directoryIndex);
+    void showDirectoryErrors(const QString &dirId);
     void copyToClipboard(const QString &text);
     void updateStatusIconAndTooltip();
-    QIcon loadForkAwesomeIcon(const QString &name, int size = 32) const;
-    QString formatFileSize(quint64 fileSizeInByte) const;
-    QString substituteTilde(const QString &path) const;
+    void saveSettings();
 
 Q_SIGNALS:
     /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
@@ -180,9 +185,7 @@ private Q_SLOTS:
     void handleDirStatisticsChanged();
     void handleErrorsCleared();
     void handleAboutDialogDeleted();
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
     void handleWebViewDeleted();
-#endif
     void handleNewNotification(CppUtilities::DateTime when, const QString &msg);
     void handleSystemdServiceError(const QString &context, const QString &name, const QString &message);
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
@@ -221,9 +224,7 @@ private:
     QtGui::DBusStatusNotifier m_dbusNotifier;
     std::vector<Data::SyncthingLogEntry> m_notifications;
     QtForkAwesome::QuickImageProvider *m_imageProvider;
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
     QtGui::WebViewDialog *m_webViewDlg;
-#endif
     int m_currentConnectionConfig;
     bool m_hasInternalErrors;
     bool m_initialized;
