@@ -3,6 +3,12 @@
 
 #include <QMenu>
 
+QT_FORWARD_DECLARE_CLASS(QHBoxLayout)
+
+#if defined(Q_OS_WINDOWS) && (QT_VERSION >= QT_VERSION_CHECK(6, 1, 0))
+#define TRAY_MENU_HANDLE_WINDOWS11_STYLE
+#endif
+
 namespace QtGui {
 
 class TrayIcon;
@@ -10,30 +16,51 @@ class TrayWidget;
 
 class TrayMenu : public QMenu {
     Q_OBJECT
-    Q_PROPERTY(bool windowed READ isWindowed WRITE setWindowed)
 
 public:
+    enum class WindowType {
+        Popup,
+        NormalWindow,
+        CustomWindow,
+        None,
+    };
+
     explicit TrayMenu(TrayIcon *trayIcon = nullptr, QWidget *parent = nullptr);
 
     QSize sizeHint() const override;
     TrayWidget &widget();
     const TrayWidget &widget() const;
     TrayIcon *icon();
-    bool isWindowed() const;
+    WindowType windowType() const;
+    void setWindowType(int windowType);
+    void setWindowType(WindowType windowType);
+
+Q_SIGNALS:
+    void positioningSettingsChanged();
 
 public Q_SLOTS:
     void showUsingPositioningSettings();
-    void setWindowed(bool windowed);
 
 protected:
+    bool event(QEvent *) override;
     void mouseReleaseEvent(QMouseEvent *) override;
     void mousePressEvent(QMouseEvent *) override;
+    void moveEvent(QMoveEvent *) override;
+    void resizeEvent(QResizeEvent *) override;
     void paintEvent(QPaintEvent *) override;
+    void focusOutEvent(QFocusEvent *) override;
 
 private:
+    void updateContentMargins();
+
+    QHBoxLayout *m_layout;
     TrayWidget *m_trayWidget;
     TrayIcon *m_trayIcon;
-    bool m_windowed = false;
+    WindowType m_windowType;
+    bool m_startedSystemWindowCommand;
+#ifdef TRAY_MENU_HANDLE_WINDOWS11_STYLE
+    bool m_isWindows11Style;
+#endif
 };
 
 inline TrayWidget &TrayMenu::widget()
@@ -51,9 +78,9 @@ inline TrayIcon *TrayMenu::icon()
     return m_trayIcon;
 }
 
-inline bool TrayMenu::isWindowed() const
+inline TrayMenu::WindowType TrayMenu::windowType() const
 {
-    return m_windowed;
+    return m_windowType;
 }
 
 } // namespace QtGui
