@@ -20,6 +20,7 @@
 
 // use meta-data of syncthingtray application here
 #include "resources/../../tray/resources/config.h"
+#include "resources/../../tray/resources/qtconfig.h"
 
 #include "ui_traywidget.h"
 
@@ -57,7 +58,6 @@ using namespace std;
 
 namespace QtGui {
 
-QWidget *TrayWidget::s_dialogParent = nullptr;
 SettingsDialog *TrayWidget::s_settingsDlg = nullptr;
 Wizard *TrayWidget::s_wizard = nullptr;
 QtUtilities::AboutDialog *TrayWidget::s_aboutDlg = nullptr;
@@ -73,9 +73,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     : QWidget(parent)
     , m_menu(parent)
     , m_ui(new Ui::TrayWidget)
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
     , m_webViewDlg(nullptr)
-#endif
     , m_internalErrorsButton(nullptr)
     , m_notifier(m_connection)
     , m_dirModel(m_connection)
@@ -141,7 +139,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     showLogButton->setFlat(true);
     cornerFrameLayout->addWidget(showLogButton);
     auto *scanAllButton = new QPushButton(m_cornerFrame);
-    scanAllButton->setToolTip(tr("Rescan all directories"));
+    scanAllButton->setToolTip(tr("Rescan all folders"));
     scanAllButton->setIcon(QIcon(QStringLiteral("refresh.fa")));
     scanAllButton->setFlat(true);
     cornerFrameLayout->addWidget(scanAllButton);
@@ -161,9 +159,9 @@ TrayWidget::TrayWidget(TrayMenu *parent)
 
     // setup other widgets
     m_ui->notificationsPushButton->setHidden(true);
-    m_ui->globalTextLabel->setPixmap(QIcon(QStringLiteral("globe.fa")).pixmap(16));
-    m_ui->localTextLabel->setPixmap(QIcon(QStringLiteral("home.fa")).pixmap(16));
-    updateTraffic();
+    updateTrafficText();
+    setTrafficPixmaps(true);
+    setLabelPixmaps();
 
     // add actions from right-click menu if it is not available
 #ifndef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
@@ -195,7 +193,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     // connect signals and slots
     connect(m_ui->statusPushButton, &QPushButton::clicked, this, &TrayWidget::changeStatus);
     connect(m_ui->aboutPushButton, &QPushButton::clicked, this, &TrayWidget::showAboutDialog);
-    connect(m_ui->webUiPushButton, &QPushButton::clicked, this, &TrayWidget::showWebUi);
+    connect(m_ui->webUiPushButton, &QPushButton::clicked, this, &TrayWidget::showWebUI);
     connect(m_ui->settingsPushButton, &QPushButton::clicked, this, &TrayWidget::showSettingsDialog);
     connect(&m_connection, &SyncthingConnection::statusChanged, this, &TrayWidget::handleStatusChanged);
     connect(&m_connection, &SyncthingConnection::trafficChanged, this, &TrayWidget::updateTraffic);
@@ -235,7 +233,8 @@ TrayWidget::~TrayWidget()
         s_instances.erase(i);
     }
     if (s_instances.empty()) {
-        delete s_dialogParent;
+        delete s_settingsDlg;
+        delete s_aboutDlg;
         QCoreApplication::quit();
     } else if (s_instances.size() == 1) {
         s_instances.front()->updateIconAndTooltip();
@@ -244,19 +243,19 @@ TrayWidget::~TrayWidget()
 
 SettingsDialog *TrayWidget::settingsDialog()
 {
-    if (!s_dialogParent) {
-        s_dialogParent = new QWidget();
-    }
     if (!s_settingsDlg) {
-        s_settingsDlg = new SettingsDialog(s_instances.size() < 2 ? &m_connection : nullptr, s_dialogParent);
+        s_settingsDlg = new SettingsDialog(s_instances.size() < 2 ? &m_connection : nullptr);
         connect(s_settingsDlg, &SettingsDialog::wizardRequested, this, &TrayWidget::showWizard);
         connect(s_settingsDlg, &SettingsDialog::applied, &TrayWidget::applySettingsOnAllInstances);
+        if (m_menu) {
+            connect(m_menu, &TrayMenu::positioningSettingsChanged, s_settingsDlg, &SettingsDialog::resetPositioningSettings);
+        }
 
         // save settings to disk when applied
         // note: QCoreApplication::aboutToQuit() does not work reliably but terminating only at the
         //       end of the session is a common use-case for the tray application. So workaround this
         //       by simply saving the settings immediately.
-        connect(s_settingsDlg, &SettingsDialog::applied, &Settings::save);
+        connect(s_settingsDlg, &SettingsDialog::applied, this, &TrayWidget::saveSettings);
     }
     return s_settingsDlg;
 }
@@ -281,7 +280,7 @@ void TrayWidget::showWizard()
         connect(s_wizard, &Wizard::destroyed, this, [] { s_wizard = nullptr; });
         connect(s_wizard, &Wizard::settingsDialogRequested, this, &TrayWidget::showSettingsDialog);
         connect(s_wizard, &Wizard::openLauncherSettingsRequested, this, &TrayWidget::showLauncherSettings);
-        connect(s_wizard, &Wizard::openSyncthingRequested, this, &TrayWidget::showWebUi);
+        connect(s_wizard, &Wizard::openSyncthingRequested, this, &TrayWidget::showWebUI);
         connect(s_wizard, &Wizard::settingsChanged, this, &TrayWidget::applySettingsChangesFromWizard);
     }
     showDialog(s_wizard, centerWidgetAvoidingOverflow(s_wizard));
@@ -297,7 +296,7 @@ void TrayWidget::applySettingsChangesFromWizard()
     // consider the settings applied instantly if there's no tray widget instance
     if (s_instances.empty()) {
         if (s_wizard) {
-            s_wizard->handleConfigurationApplied();
+            s_wizard->handleConfigurationApplied(QString(), &m_connection);
         }
         return;
     }
@@ -326,14 +325,19 @@ void TrayWidget::applySettingsChangesFromWizard()
     }
 }
 
+void TrayWidget::saveSettings()
+{
+    Settings::save();
+    if (const auto &error = Settings::values().error; !error.isEmpty()) {
+        QMessageBox::critical(nullptr, QCoreApplication::applicationName(), error);
+    }
+}
+
 void TrayWidget::showAboutDialog()
 {
-    if (!s_dialogParent) {
-        s_dialogParent = new QWidget();
-    }
     if (!s_aboutDlg) {
-        s_aboutDlg = new AboutDialog(
-            s_dialogParent, QString(), aboutDialogAttribution(), QString(), {}, QStringLiteral(APP_URL), QString(), aboutDialogImage());
+        s_aboutDlg
+            = new AboutDialog(nullptr, QString(), aboutDialogAttribution(), QString(), {}, QStringLiteral(APP_URL), QString(), aboutDialogImage());
         s_aboutDlg->setWindowTitle(tr("About") + QStringLiteral(" - " APP_NAME));
         s_aboutDlg->setWindowIcon(QIcon(QStringLiteral(":/icons/hicolor/scalable/app/syncthingtray.svg")));
     }
@@ -341,23 +345,20 @@ void TrayWidget::showAboutDialog()
     showDialog(s_aboutDlg);
 }
 
-void TrayWidget::showWebUi()
+void TrayWidget::showWebUI()
 {
+    auto *const dlg = QtGui::showWebUI(m_connection.syncthingUrl(), m_selectedConnection, m_webViewDlg, this);
 #ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
-    if (Settings::values().webView.disabled) {
-#endif
-        QDesktopServices::openUrl(m_connection.syncthingUrl());
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
-    } else {
-        if (!m_webViewDlg) {
-            m_webViewDlg = new WebViewDialog(this);
-            if (m_selectedConnection) {
-                m_webViewDlg->applySettings(*m_selectedConnection, true);
-            }
-            connect(m_webViewDlg, &WebViewDialog::destroyed, this, &TrayWidget::handleWebViewDeleted);
-        }
-        showDialog(m_webViewDlg);
+    if (!dlg) {
+        return;
     }
+    if (!m_webViewDlg) {
+        m_webViewDlg = dlg;
+        connect(m_webViewDlg, &WebViewDialog::destroyed, this, &TrayWidget::handleWebViewDeleted);
+    }
+    showDialog(m_webViewDlg);
+#else
+    Q_UNUSED(dlg)
 #endif
 }
 
@@ -399,7 +400,7 @@ void TrayWidget::showUsingPositioningSettings()
 void TrayWidget::showInternalError(
     const QString &errorMessage, SyncthingErrorCategory category, int networkError, const QNetworkRequest &request, const QByteArray &response)
 {
-    if (!InternalError::isRelevant(connection(), category, networkError)) {
+    if (!InternalError::isRelevant(connection(), category, errorMessage, networkError)) {
         return;
     }
     InternalErrorsDialog::addError(errorMessage, request.url(), response);
@@ -459,17 +460,22 @@ void TrayWidget::handleStatusChanged(SyncthingStatus status)
 {
     switch (status) {
     case SyncthingStatus::Disconnected:
-        m_ui->statusPushButton->setText(tr("Connect"));
-        m_ui->statusPushButton->setToolTip(tr("Not connected to Syncthing, click to connect"));
-        m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("refresh.fa")));
-        m_ui->statusPushButton->setHidden(false);
-        updateTraffic(); // ensure previous traffic statistics are no longer shown
-        if (m_applyingSettingsForWizard) {
-            concludeWizard(tr("Unable to establish connection to Syncthing."));
-        }
-        return;
     case SyncthingStatus::Reconnecting:
-        m_ui->statusPushButton->setHidden(true);
+        if (status == SyncthingStatus::Reconnecting || m_connection.isConnecting()) {
+            m_ui->statusPushButton->setText(tr("Connecting …"));
+            m_ui->statusPushButton->setToolTip(tr("Establishing connection to Syncthing …"));
+            m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("refresh.fa")));
+            m_ui->statusPushButton->setEnabled(false);
+        } else {
+            m_ui->statusPushButton->setText(tr("Connect"));
+            m_ui->statusPushButton->setToolTip(tr("Not connected to Syncthing, click to connect"));
+            m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("refresh.fa")));
+            m_ui->statusPushButton->setEnabled(true);
+            updateTraffic(); // ensure previous traffic statistics are no longer shown
+            if (m_applyingSettingsForWizard) {
+                concludeWizard(tr("Unable to establish connection to Syncthing."));
+            }
+        }
         return;
     case SyncthingStatus::Idle:
     case SyncthingStatus::Scanning:
@@ -478,13 +484,13 @@ void TrayWidget::handleStatusChanged(SyncthingStatus status)
         m_ui->statusPushButton->setText(tr("Pause"));
         m_ui->statusPushButton->setToolTip(tr("Syncthing is running, click to pause all devices"));
         m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("pause.fa")));
-        m_ui->statusPushButton->setHidden(false);
+        m_ui->statusPushButton->setEnabled(true);
         break;
     case SyncthingStatus::Paused:
         m_ui->statusPushButton->setText(tr("Continue"));
         m_ui->statusPushButton->setToolTip(tr("At least one device is paused, click to resume"));
         m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("play.fa")));
-        m_ui->statusPushButton->setHidden(false);
+        m_ui->statusPushButton->setEnabled(true);
         break;
     default:;
     }
@@ -594,7 +600,7 @@ void TrayWidget::applySettings(const QString &connectionConfig)
         }
     }
     if (m_menu) {
-        m_menu->setWindowed(settings.appearance.windowed);
+        m_menu->setWindowType(settings.appearance.windowType);
     }
 
     // update status icon and text of tray icon because reconnect interval might have changed
@@ -618,17 +624,34 @@ void TrayWidget::applySettings(const QString &connectionConfig)
 
 bool TrayWidget::event(QEvent *event)
 {
+    const auto res = QWidget::event(event);
     switch (event->type()) {
     case QEvent::PaletteChange:
         setBrightColorsOfModelsAccordingToPalette();
+        setLabelPixmaps();
+        setTrafficPixmaps(true);
+        break;
+    case QEvent::LanguageChange:
+        m_ui->retranslateUi(this);
+        applyLauncherSettings(false, true, false);
+        handleStatusChanged(m_connection.status());
+        if (m_menu && m_menu->icon()) {
+            m_menu->icon()->updateStatusIconAndText();
+        }
         break;
     default:;
     }
-    return QWidget::event(event);
+    return res;
 }
 
 void TrayWidget::applySettingsOnAllInstances()
 {
+    auto &qtSettings = Settings::values().qt;
+    qtSettings.apply();
+    if (qtSettings.hasLocaleChanged()) {
+        QtUtilities::TranslationFiles::clearTranslationFiles();
+        LOAD_QT_TRANSLATIONS;
+    }
     for (TrayWidget *instance : s_instances) {
         instance->applySettings();
     }
@@ -640,7 +663,7 @@ void TrayWidget::openDir(const SyncthingDir &dir)
     if (QDir(path).exists()) {
         openLocalFileOrDir(path);
     } else {
-        QMessageBox::warning(this, QCoreApplication::applicationName(), tr("The directory <i>%1</i> does not exist on the local machine.").arg(path));
+        QMessageBox::warning(this, QCoreApplication::applicationName(), tr("The folder <i>%1</i> does not exist on the local machine.").arg(path));
     }
 }
 
@@ -651,7 +674,7 @@ void TrayWidget::openItemDir(const SyncthingItemDownloadProgress &item)
         openLocalFileOrDir(containingDir.path());
     } else {
         QMessageBox::warning(this, QCoreApplication::applicationName(),
-            tr("The containing directory <i>%1</i> does not exist on the local machine.").arg(item.fileInfo.filePath()));
+            tr("The containing folder <i>%1</i> does not exist on the local machine.").arg(item.fileInfo.filePath()));
     }
 }
 
@@ -701,7 +724,7 @@ void TrayWidget::showRecentChangesContextMenu(const QPoint &position)
                 tr("Copy device ID")),
         &QAction::triggered, this, copyRole(SyncthingRecentChangesModel::ModifiedBy));
     connect(menu.addAction(QIcon::fromTheme(QStringLiteral("folder"), QIcon(QStringLiteral(":/icons/hicolor/scalable/places/folder.svg"))),
-                tr("Copy directory ID")),
+                tr("Copy folder ID")),
         &QAction::triggered, this, copyRole(SyncthingRecentChangesModel::DirectoryId));
     showViewMenu(position, *m_ui->recentChangesTreeView, menu);
 }
@@ -729,38 +752,21 @@ void TrayWidget::changeStatus()
 
 void TrayWidget::updateTraffic()
 {
-    if (m_ui->trafficFormWidget->isHidden()) {
-        return;
+    if (updateTrafficText()) {
+        setTrafficPixmaps();
     }
+}
 
-    // render traffic icons the first time the function is called
-    static const auto trafficIcons = [this]() {
-        const auto size = QSize(16, 13);
-        const auto &palette = m_ui->trafficFormWidget->palette(); // FIXME: make this aware of palette changes
-        const auto colorBackground = palette.color(QPalette::Window);
-        const auto colorActive = palette.color(QPalette::WindowText);
-        const auto colorInactive = QColor((colorActive.red() + colorBackground.red()) / 2, (colorActive.green() + colorBackground.green()) / 2,
-            (colorActive.blue() + colorBackground.blue()) / 2);
-        const auto renderIcon
-            = [&size](QtForkAwesome::Icon icon, const QColor &color) { return QtForkAwesome::Renderer::global().pixmap(icon, size, color); };
-        struct {
-            QPixmap uploadIconActive;
-            QPixmap uploadIconInactive;
-            QPixmap downloadIconActive;
-            QPixmap downloadIconInactive;
-        } icons;
-        icons.uploadIconActive = renderIcon(QtForkAwesome::Icon::CloudUpload, colorActive);
-        icons.uploadIconInactive = renderIcon(QtForkAwesome::Icon::CloudUpload, colorInactive);
-        icons.downloadIconActive = renderIcon(QtForkAwesome::Icon::CloudDownload, colorActive);
-        icons.downloadIconInactive = renderIcon(QtForkAwesome::Icon::CloudDownload, colorInactive);
-        return icons;
-    }();
+bool TrayWidget::updateTrafficText()
+{
+    if (m_ui->trafficFormWidget->isHidden()) {
+        return false;
+    }
 
     // update text and whether to use active/inactive icons
     m_ui->inTrafficLabel->setText(trafficString(m_connection.totalIncomingTraffic(), m_connection.totalIncomingRate()));
     m_ui->outTrafficLabel->setText(trafficString(m_connection.totalOutgoingTraffic(), m_connection.totalOutgoingRate()));
-    m_ui->trafficInTextLabel->setPixmap(m_connection.totalIncomingRate() > 0.0 ? trafficIcons.downloadIconActive : trafficIcons.downloadIconInactive);
-    m_ui->trafficOutTextLabel->setPixmap(m_connection.totalOutgoingRate() > 0.0 ? trafficIcons.uploadIconActive : trafficIcons.uploadIconInactive);
+    return true;
 }
 
 void TrayWidget::updateOverallStatistics()
@@ -887,12 +893,10 @@ Settings::Systemd::ServiceStatus TrayWidget::applySystemdSettings(bool reconnect
 }
 #endif
 
-#ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
 void TrayWidget::handleWebViewDeleted()
 {
     m_webViewDlg = nullptr;
 }
-#endif
 
 void TrayWidget::handleNewNotification(DateTime when, const QString &msg)
 {
@@ -926,13 +930,13 @@ void TrayWidget::concludeWizard(const QString &errorMessage)
     }
     m_applyingSettingsForWizard = false;
     if (s_wizard) {
-        s_wizard->handleConfigurationApplied(errorMessage);
+        s_wizard->handleConfigurationApplied(errorMessage, &m_connection);
     }
 }
 
 void TrayWidget::showDialog(QWidget *dlg, bool maximized)
 {
-    if (m_menu && !m_menu->isWindowed()) {
+    if (m_menu && m_menu->windowType() != TrayMenu::WindowType::NormalWindow) {
         m_menu->close();
     }
     if (maximized) {
@@ -945,11 +949,42 @@ void TrayWidget::showDialog(QWidget *dlg, bool maximized)
 
 void TrayWidget::setBrightColorsOfModelsAccordingToPalette()
 {
-    const auto brightColors = isPaletteDark(palette());
+    auto &qtSettings = Settings::values().qt;
+    qtSettings.reevaluatePaletteAndDefaultIconTheme();
+    const auto brightColors = qtSettings.isPaletteDark();
     m_dirModel.setBrightColors(brightColors);
     m_devModel.setBrightColors(brightColors);
     m_dlModel.setBrightColors(brightColors);
     m_recentChangesModel.setBrightColors(brightColors);
 }
 
+void TrayWidget::setLabelPixmaps()
+{
+    m_ui->globalTextLabel->setPixmap(QIcon(QStringLiteral("globe.fa")).pixmap(16));
+    m_ui->localTextLabel->setPixmap(QIcon(QStringLiteral("home.fa")).pixmap(16));
+}
+
+void TrayWidget::setTrafficPixmaps(bool recompute)
+{
+    if (recompute) {
+        const auto size = QSize(16, 13);
+        const auto &palette = m_ui->trafficFormWidget->palette();
+        const auto colorBackground = palette.color(QPalette::Window);
+        const auto colorActive = palette.color(QPalette::WindowText);
+        const auto colorInactive = QColor((colorActive.red() + colorBackground.red()) / 2, (colorActive.green() + colorBackground.green()) / 2,
+            (colorActive.blue() + colorBackground.blue()) / 2);
+        const auto renderIcon
+            = [&size](QtForkAwesome::Icon icon, const QColor &color) { return QtForkAwesome::Renderer::global().pixmap(icon, size, color); };
+        m_trafficIcons.uploadIconActive = renderIcon(QtForkAwesome::Icon::CloudUpload, colorActive);
+        m_trafficIcons.uploadIconInactive = renderIcon(QtForkAwesome::Icon::CloudUpload, colorInactive);
+        m_trafficIcons.downloadIconActive = renderIcon(QtForkAwesome::Icon::CloudDownload, colorActive);
+        m_trafficIcons.downloadIconInactive = renderIcon(QtForkAwesome::Icon::CloudDownload, colorInactive);
+    }
+
+    m_ui->trafficInTextLabel->setPixmap(
+        m_connection.totalIncomingRate() > 0.0 ? m_trafficIcons.downloadIconActive : m_trafficIcons.downloadIconInactive);
+    m_ui->trafficOutTextLabel->setPixmap(
+        m_connection.totalOutgoingRate() > 0.0 ? m_trafficIcons.uploadIconActive : m_trafficIcons.uploadIconInactive);
+}
+
 } // namespace QtGui
